@@ -3,6 +3,7 @@
 #' @import httr plyr
 #' @param snp SNP name. 
 #' @param df Return data.frame (TRUE) or not (FALSE) - default = FALSE.
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}.
 #' @return List of genotypes for all users at a certain SNP, or data.frame
 #' @export 
 #' @examples \dontrun{
@@ -10,12 +11,12 @@
 #' allgensnp('rs7412', df=TRUE)
 #' }
 
-allgensnp <- function(snp = NA, df = FALSE)
+allgensnp <- function(snp = NA, df = FALSE, ...)
 {
   url = "http://opensnp.org/snps/"
   url2 <- paste(url, snp, '.json', sep='')
   message(url2)
-  res <- GET(url2)
+  res <- GET(url2, ...)
   stop_for_status(res)
   out <- content(res)
   if(df == TRUE)
@@ -25,4 +26,4 @@ allgensnp <- function(snp = NA, df = FALSE)
                    "user_id","genotype_id","genotype")
     df
   } else { out }
-}
\ No newline at end of file
+}
