@@ -4,6 +4,7 @@
 #' @param snp SNP name.
 #' @param userid ID of openSNP user. 
 #' @param df Return data.frame (TRUE) or not (FALSE) - default = FALSE.
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}.
 #' @return List (or data.frame) of genotypes for specified user(s) at a certain SNP.
 #' @export 
 #' @examples \dontrun{
@@ -12,12 +13,12 @@
 #' genotypes('rs9939609', userid='1-2', df=FALSE)
 #' }
 
-genotypes <- function(snp = NA, userid = NA, df = FALSE) 
+genotypes <- function(snp = NA, userid = NA, df = FALSE, ...)
 {
   url = "http://opensnp.org/snps/json/"
   url2 <- paste(url, snp, "/", userid, '.json', sep='')
   message(url2)
-  res <- GET(url2)
+  res <- GET(url2, ...)
   stop_for_status(res)
   genotypes_ <- content(res)
   
@@ -33,4 +34,4 @@ genotypes <- function(snp = NA, userid = NA, df = FALSE)
       return( df )
     }
   } else { genotypes_ }
-}
\ No newline at end of file
+}
