@@ -3,6 +3,7 @@
 #' @import httr plyr
 #' @param phenotypeid ID of openSNP phenotype. 
 #' @param return_ Return data.frame (TRUE) or not (FALSE) - default = FALSE.
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}.
 #' @return List of description of phenotype, list of known variants, or data.frame
 #' 		of variants for each user with that phenotype.
 #' @export 
@@ -10,14 +11,19 @@
 #' phenotypes_byid(phenotypeid=12, return_ = 'desc')
 #' phenotypes_byid(phenotypeid=12, return_ = 'knownvars')
 #' phenotypes_byid(phenotypeid=12, return_ = 'users')
+#' 
+#' # pass on curl options
+#' library("httr")
+#' phenotypes_byid(phenotypeid=12, return_ = 'desc', config=c(verbose(), timeout(1)))
+#' phenotypes_byid(phenotypeid=12, return_ = 'desc', config=verbose())
 #' }
 
-phenotypes_byid <- function(phenotypeid = NA, return_ = c('description','knownvars','users')) 
+phenotypes_byid <- function(phenotypeid = NA, return_ = c('description','knownvars','users'), ...)
 {
   url = "http://opensnp.org/phenotypes/json/variations/"
   url2 <- paste(url, phenotypeid, '.json', sep='')
   message(url2)
-  res <- GET(url2)
+  res <- GET(url2, ...)
   stop_for_status(res)
   out <- content(res) 
   
@@ -32,4 +38,4 @@ phenotypes_byid <- function(phenotypeid = NA, return_ = c('description','knownva
     {
       ldply(out$users, data.frame, stringsAsFactors = FALSE)
     }
-}
\ No newline at end of file
+}
